<?php

class Easy2MapImg {

    const plugin_name = 'Easy2MapImg';
    const min_php_version = '5.0';
    const min_wp_version = '3.0';
    // Used to uniquely identify this plugin's menu page in the WP manager
    const admin_menu_slug = 'easy2mapimg';
    const e2m_version = '2.0.4';

    //MERCURIAL COMMIT TEST 2
    /** Adds the necessary JavaScript and/or CSS to the pages to enable the Ajax search. */
    public static function head() {

        $src_Easy2MapImgAPI = "http://maps.google.com/maps/api/js?sensor=true";
        $src_Easy2MapImg = plugins_url('scripts/easy2mapimg.js', dirname(__FILE__));
        $src_Xml2json = plugins_url('scripts/jquery.xml2json.js', dirname(__FILE__));
        $src_Carousel = plugins_url('scripts/carousel.js', dirname(__FILE__));

        wp_register_script('easy2mapimg_js_api', $src_Easy2MapImgAPI);
        wp_register_script('easy2mapimg_js_easy2map', $src_Easy2MapImg);
        wp_register_script('easy2mapimg_js_Xml2json', $src_Xml2json);
        wp_register_script('easy2mapimg_js_Carousel', $src_Carousel);

        wp_enqueue_script('easy2mapimg_js_api');
        wp_enqueue_script('easy2mapimg_js_easy2map');
        wp_enqueue_script('easy2mapimg_js_Xml2json');
        wp_enqueue_script('easy2mapimg_js_Carousel');
    }

    /** The main function for this plugin, similar to __construct() */
    public static function initialize() {

        Easy2MapImgTest::min_php_version(self::min_php_version);
        Easy2MapImgTest::min_wordpress_version(self::min_wp_version);
        Easy2MapImgTest::php_extensions(array('gd'));
        Easy2MapImgTest::print_notices();

        wp_enqueue_script('jquery'); // make sure jQuery is loaded!
        if (is_admin()) {
            wp_enqueue_script('jquery-ui-draggable');
            wp_enqueue_script('jquery-ui-droppable');
        }
    }

    /**     * Register the shortcodes used */
    public static function register_shortcodes() {
        add_shortcode('easy2mapimg', 'Easy2MapImg::retrieve_map');
    }

    public static function create_admin_tables() {

        global $wpdb;
        $error = "<div id='error' class='error'><p>%s</p></div>";
        $map_table = $wpdb->prefix . "easy2mapimg_maps";
        $map_points_table = $wpdb->prefix . "easy2mapimg_map_points";
        $map_point_templates_table = $wpdb->prefix . "easy2mapimg_pin_templates";
        $map_templates_table = $wpdb->prefix . "easy2mapimg_templates";
        $map_themes_table = $wpdb->prefix . "easy2mapimg_themes";

        $result = $wpdb->get_var("show tables like '$map_table'");

        if (strtolower($result) != strtolower($map_table)) {

            $SQL = "CREATE TABLE `$map_table` (
          `ID` bigint(20) NOT NULL AUTO_INCREMENT,
          `TemplateID` bigint(20) DEFAULT NULL,
          `MapName` varchar(256) DEFAULT NULL,
          `MapTitle` varchar(512) DEFAULT NULL,
          `DefaultPinImage` varchar(256) DEFAULT NULL,
          `Settings` text,
          `LastInvoked` datetime DEFAULT NULL,
          `PolyLines` text,
          `CSSValues` text,
          `CSSValuesPhoto` text,
          `CSSValuesMap` text,
          `MapHTML` text,
          `IsActive` smallint(6) DEFAULT NULL,
          `ThemeID` bigint(2) DEFAULT NULL,
          PRIMARY KEY (`ID`),
          UNIQUE KEY `ID_UNIQUE` (`ID`)
        ) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=latin1";

            if (!$wpdb->query($SQL)) {
                echo sprintf($error, __("Could not create easy2map photo maps table.", 'easy2map'));
                return;
            }
        }

        //does themeID column exist?
        $arrThemeIDColumnFound = $wpdb->get_results("SELECT * FROM information_schema.COLUMNS 
        WHERE TABLE_NAME = '$map_table' AND TABLE_SCHEMA = '" . DB_NAME . "' AND COLUMN_NAME = 'ThemeID';");

        //add themeID table column
        if (count($arrThemeIDColumnFound) === 0) {
            $wpdb->query("ALTER TABLE $map_table ADD ThemeID int(11) DEFAULT NULL;");
        }

        $result = $wpdb->get_var("show tables like '$map_points_table'");

        if (strtolower($result) != strtolower($map_points_table)) {

            $SQL = "CREATE TABLE `$map_points_table` (
            `ID` bigint(20) NOT NULL AUTO_INCREMENT,
            `MapID` bigint(20) DEFAULT NULL,
            `CreatedByUserID` bigint(20) DEFAULT NULL,
            `LatLong` varchar(128) DEFAULT NULL,
            `Title` varchar(512) DEFAULT NULL,
            `PinImageURL` varchar(512) DEFAULT NULL,
            `Settings` varchar(512) DEFAULT NULL,
            `DetailsHTML` text,
            `DetailsText` text,
            `PinImageSmall` varchar(512) DEFAULT NULL,
            `PinImageMedium` varchar(512) DEFAULT NULL,
            `PinImageLarge` varchar(512) DEFAULT NULL,
            PRIMARY KEY (`ID`),
            UNIQUE KEY `ID_UNIQUE` (`ID`),
            KEY `wp_easy2mapimg_map_points_MapID` (`MapID`),
            CONSTRAINT `easy2mapimg_map_points_MapID` FOREIGN KEY (`MapID`) REFERENCES `$map_table` (`ID`) ON DELETE NO ACTION ON UPDATE NO ACTION
          ) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=latin1";

            if (!$wpdb->query($SQL)) {
                echo sprintf($error, __("Could not create easy2map photo pins table.", 'easy2mapimg'));
                return;
            }
        }

        $result = $wpdb->get_var("show tables like '$map_point_templates_table'");

        if (strtolower($result) != strtolower($map_point_templates_table)) {

            $SQL = "CREATE TABLE `$map_point_templates_table` (
            `ID` int(11) NOT NULL AUTO_INCREMENT,
            `TemplateName` varchar(128) DEFAULT NULL,
            `TemplateHTML` text,
            PRIMARY KEY (`ID`),
            UNIQUE KEY `ID_UNIQUE` (`ID`)
          ) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=latin1";

            if (!$wpdb->query($SQL)) {
                echo sprintf($error, __("Could not create easy2map pin templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert1 = "INSERT INTO `$map_point_templates_table`
            (`TemplateName`,
            `TemplateHTML`)
            VALUES
            ('Thumbnail Image on Left', 
            '<table style=\"margin-top:8px;overflow:hidden;vertical-align:middle;width:325px;border-radius:0px;margin-left:5px;margin-right:20px;\"><tr><td style=\"vertical-align:top;padding:6px;border-style:solid;border-width:1px;vertical-align:top;border-color:#FFFFFF;\"><img style=\"border:0px solid #000000;border-radius: 0px;\" src=\"http://easy2map.com/images/css_templates/thumbnail20120424025713000000_CSS.png\" border=\"0\"></td><td style=\"width:100%;vertical-align:top;\"><p align=\"left\" style=\"border-color:#E53840;border-style:solid;border-width:1px;color:#FFFFFF;font-family:Arial, Helvetica, sans-serif;font-size:14px;font-weight:bold;padding:4px;text-align:left;text-decoration:none;vertical-align:middle;background-color:#E53840;border-radius:0px;margin:3px;\">Section 1</p><p align=\"left\" style=\"margin:3px;background-color:#009AD7;border-color:#009AD7;border-style:solid;border-width:1px;color:#FFFFFF;font-family:Arial, Helvetica, sans-serif;font-size:13px;font-weight:bold;padding:4px;text-align:left;text-decoration:none;vertical-align:top;border-radius:0px;\">Section 2</p><p align=\"left\" style=\"margin:3px;background-color:#DADADA;border-color:#DADADA;border-style:solid;border-width:1px;color:#000000;font-family:Arial, Helvetica, sans-serif;font-size:13px;font-weight:bold;padding:4px;text-align:left;text-decoration:none;vertical-align:middle;border-radius:0px;\">Section 3</p><p align=\"left\" style=\"margin:3px;background-color:#FFFFFF;border-color:#EBEBEB;border-style:solid;border-width:1px;color:#000000;font-size:12px;font-weight:normal;padding:4px;text-align:left;border-radius:0px;\">Section 4</p></td></tr></table>')";

            if (!$wpdb->query($SQLInsert1)) {
                echo sprintf($error, __("Could not insert data into easy2map pin templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert2 = "INSERT INTO `$map_point_templates_table`
            (`TemplateName`,
            `TemplateHTML`)
            VALUES
            ('Thumbnail Image on Right',
            '<table style=\"margin-top:8px;overflow:hidden;vertical-align:middle;width:325px;border-radius:0px;margin-left:5px;margin-right:20px;\"><tr><td style=\"width:100%;vertical-align:top;\"><p align=\"left\" style=\"border-color:#E53840;border-style:solid;border-width:1px;color:#FFFFFF;font-family:Arial, Helvetica, sans-serif;font-size:14px;font-weight:bold;padding:4px;text-align:left;text-decoration:none;vertical-align:middle;background-color:#E53840;border-radius:0px;margin:3px;\">Section 1</p><p align=\"left\" style=\"margin:3px;background-color:#009AD7;border-color:#009AD7;border-style:solid;border-width:1px;color:#FFFFFF;font-family:Arial, Helvetica, sans-serif;font-size:13px;font-weight:bold;padding:4px;text-align:left;text-decoration:none;vertical-align:top;border-radius:0px;\">Section 2</p><p align=\"left\" style=\"margin:3px;background-color:#DADADA;border-color:#DADADA;border-style:solid;border-width:1px;color:#000000;font-family:Arial, Helvetica, sans-serif;font-size:13px;font-weight:bold;padding:4px;text-align:left;text-decoration:none;vertical-align:middle;border-radius:0px;\">Section 3</p><p align=\"left\" style=\"margin:3px;background-color:#FFFFFF;border-color:#EBEBEB;border-style:solid;border-width:1px;color:#000000;font-size:12px;font-weight:normal;padding:4px;text-align:left;border-radius:0px;\">Section 4</p></td><td style=\"vertical-align:top;padding:6px;border-style:solid;border-width:1px;vertical-align:top;border-color:#FFFFFF;\"><img style=\"border:0px solid #000000;border-radius: 0px;\" src=\"http://easy2map.com/images/css_templates/thumbnail20120424025713000000_CSS.png\" border=\"0\"></td></tr></table>')";

            if (!$wpdb->query($SQLInsert2)) {
                echo sprintf($error, __("Could not insert data into easy2map pin templates table.", 'easy2mapimg'));
                return;
            }
        }

        $result = $wpdb->get_var("show tables like '$map_templates_table'");

        if (strtolower($result) != strtolower($map_templates_table)) {

            $SQL = "CREATE TABLE `$map_templates_table` (
            `ID` int(11) NOT NULL AUTO_INCREMENT,
            `TemplateName` varchar(256) DEFAULT NULL,
            `ExampleImage` varchar(512) DEFAULT NULL,
            `DisplayOrder` smallint(6) DEFAULT NULL,
            `CSSValues` text,
            `CSSValuesPhoto` text,
            `CSSValuesMap` text,
            `TemplateHTML` text,
            `StyleParentOnly` smallint(6) DEFAULT NULL,
            `Active` smallint(6) DEFAULT NULL,
            PRIMARY KEY (`ID`),
            UNIQUE KEY `ID_UNIQUE` (`ID`)
          ) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=latin1";

            if (!$wpdb->query($SQL)) {
                echo sprintf($error, __("Could not create easy2map templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert3 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map On Bottom', '', 1,
            '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings height=\"120px\" max-width=\"2048px\" min-width=\"10px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\"><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-bottom-width:0px;top:0px;left:0px;min-width:10px;margin-bottom:0px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"><div align=\"center\" id=\"easy2mapslidertext\"></div><a class=\"easy2maplogo\" id=\"easy2mapphotologo\" target=\"_blank\" href=\"http://easy2map.com\"><img src=\"[siteurl]images/e2mlogosmall.png\"></a><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr><tr><td id=\"tdMap\" style=\"border-width:0px;vertical-align:top;\"><div id=\"divMap\" style=\"border-top-width:0px;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;background-color:transparent;position:relative;\"></div></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert3)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert4 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map On Top', '', 2,
            '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings height=\"120px\" max-width=\"2048px\" min-width=\"10px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\"><tr><td id=\"tdMap\" style=\"border-width:0px;vertical-align:top;\"><div id=\"divMap\" style=\"background-color:transparent;border-style:solid;border-width:1px;border-bottom-width:0px;border-color:transparent;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"></div></td></tr><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-top-width:0px;border-color:#FFFFFF;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:0px;position:relative;\"><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert4)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert5 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map On Left', '', 3,
            '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings width=\"150px\" height=\"390px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\"><tr><td id=\"tdMap\" style=\"border-width:0px;vertical-align:top;\"><div id=\"divMap\" style=\"background-color:transparent;border-style:solid;border-width:1px;border-right-width:0px;border-color:transparent;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:0px;margin-top:5px;position:relative;\"></div></td><td style=\"width:100%;\"><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-left-width:0px;border-color:#FFFFFF;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert5)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert6 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map On Right', '', 4,
            '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings width=\"150px\" height=\"390px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\"><tr><td style=\"width:100%;\"><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-right-width:0px;border-color:#FFFFFF;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td><td id=\"tdMap\" style=\"border-width:0px;vertical-align:top;\"><div id=\"divMap\" style=\"background-color:transparent;border-style:solid;border-width:1px;border-left-width:0px;border-color:transparent;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-right:5px;margin-left:0px;margin-top:5px;position:relative;\"></div></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert6)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert7 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map In Photo On Top Left - Style 1', '', 5,
            '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings box-shadow=\"none\" width=\"120px\" height=\"120px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" margin-left=\"0px\" margin-top=\"0px\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\"><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-color:#FFFFFF;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"><div id=\"divMap\" style=\"position:absolute;background-color:transparent;border-style:solid;border-width:1px;border-color:transparent;top:0px;left:0px;min-width:10px;\"></div><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert7)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert8 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map In Photo On Top Right - Style 1', '', 6,
            '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings box-shadow=\"none\" width=\"120px\" height=\"120px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" margin-right=\"0px\" margin-top=\"0px\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\"><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-color:#FFFFFF;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"><div id=\"divMap\" style=\"position:absolute;background-color:transparent;border-style:solid;border-width:1px;border-color:transparent;top:0px;right:0px;min-width:10px;\"></div><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert8)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert9 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map In Photo On Bottom Left - Style 1', '', 7,
            '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings box-shadow=\"none\" width=\"120px\" height=\"120px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" margin-left=\"0px\" margin-bottom=\"0px\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\"><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-color:#FFFFFF;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"><div id=\"divMap\" style=\"position:absolute;background-color:transparent;border-style:solid;border-width:1px;border-color:transparent;bottom:0px;left:0px;min-width:10px;\"></div><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert9)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert10 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map In Photo On Bottom Right - Style 1', '', 8,
            '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings box-shadow=\"none\" width=\"120px\" height=\"120px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" margin-right=\"0px\" margin-bottom=\"0px\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\"><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-color:#FFFFFF;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"><div id=\"divMap\" style=\"position:absolute;background-color:transparent;border-style:solid;border-width:1px;border-color:transparent;bottom:0px;right:0px;min-width:10px;\"></div><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert10)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert11 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map In Photo On Top Left - Style 2', '', 9,
            '<settings margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings box-shadow=\"-4px -4px 2px #888888\" width=\"120px\" height=\"120px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#272727\" margin-left=\"-15px\" margin-top=\"-15px\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\"><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-color:transparent;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;position:relative;\"><div id=\"divMap\" style=\"position:absolute;background-color:transparent;border-style:solid;border-width:1px;border-color:transparent;top:0px;left:0px;min-width:10px;\"></div><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert11)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }



            $SQLInsert12 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map In Photo On Top Right - Style 2', '', 10,
            '<settings margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings box-shadow=\"4px -4px 2px #888888\" width=\"120px\" height=\"120px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#272727\" margin-right=\"-15px\" margin-top=\"-15px\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\"><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-color:transparent;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;position:relative;\"><div id=\"divMap\" style=\"position:absolute;background-color:transparent;border-style:solid;border-width:1px;border-color:transparent;top:0px;right:0px;min-width:10px;\"></div><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert12)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert13 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map In Photo On Bottom Left - Style 2', '', 11,
            '<settings margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings box-shadow=\"-4px 4px 2px #888888\" width=\"120px\" height=\"120px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#272727\" margin-left=\"-15px\" margin-bottom=\"-15px\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\"><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-color:transparent;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;position:relative;\"><div id=\"divMap\" style=\"position:absolute;background-color:transparent;border-style:solid;border-width:1px;border-color:transparent;bottom:0px;left:0px;min-width:10px;\"></div><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert13)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert14 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map In Photo On Bottom Right - Style 2', '', 12,
            '<settings margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings box-shadow=\"4px 4px 2px #888888\" width=\"120px\" height=\"120px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#272727\" margin-right=\"-15px\" margin-bottom=\"-15px\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\"><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-color:transparent;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;position:relative;\"><div id=\"divMap\" style=\"position:absolute;background-color:transparent;border-style:solid;border-width:1px;border-color:transparent;bottom:0px;right:0px;min-width:10px;\"></div><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert14)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert15 = "UPDATE `$map_templates_table`
             SET `TemplateHTML` = '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\"><tr><td id=\"tdMap\" style=\"border-width:0px;vertical-align:top;\"><div id=\"divMap\" style=\"background-color:transparent;border-style:solid;border-width:1px;border-right-width:0px;border-color:transparent;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:0px;margin-top:5px;position:relative;\"></div></td><td style=\"width:100%;\"><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-left-width:0px;border-color:#FFFFFF;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr></table></div>'
             WHERE `TemplateName` = 'Map On Left'";

            $wpdb->query($SQLInsert15);

            $SQLInsert16 = "UPDATE `$map_templates_table`
             SET `TemplateHTML` = '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\"><tr><td style=\"width:100%;\"><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-right-width:0px;border-color:#FFFFFF;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td><td id=\"tdMap\" style=\"border-width:0px;vertical-align:top;\"><div id=\"divMap\" style=\"background-color:transparent;border-style:solid;border-width:1px;border-left-width:0px;border-color:transparent;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-right:5px;margin-left:0px;margin-top:5px;position:relative;\"></div></td></tr></table></div>'
             WHERE `TemplateName` = 'Map On Right'";

            $wpdb->query($SQLInsert16);

            $SQLInsert17 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map On Bottom - Drop Shadow Right', '', 1,
            '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings height=\"120px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\" style=\"position:relative;\"><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-bottom-width:0px;top:0px;left:0px;min-width:10px;margin-bottom:0px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"><div align=\"center\" id=\"easy2mapslidertext\"></div><a class=\"easy2maplogo\" id=\"easy2mapphotologo\" target=\"_blank\" href=\"http://easy2map.com\"><img src=\"[siteurl]images/e2mlogosmall.png\"></a><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr><tr><td id=\"tdMap\" style=\"border-width:0px;vertical-align:top;\"><div id=\"divMap\" style=\"border-top-width:0px;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;background-color:transparent;position:relative;\"></div><img style=\"position:absolute;bottom:-15px;right:-17px;\" src=\"[siteurl]images/map_templates/easy2map_map_shadow_right.png\" /></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert17)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert18 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map On Bottom - Drop Shadow Left', '', 1,
            '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings height=\"120px\" max-width=\"2048px\" min-width=\"10px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\" style=\"position:relative;\"><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-bottom-width:0px;top:0px;left:0px;min-width:10px;margin-bottom:0px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"><div align=\"center\" id=\"easy2mapslidertext\"></div><a class=\"easy2maplogo\" id=\"easy2mapphotologo\" target=\"_blank\" href=\"http://easy2map.com\"><img src=\"[siteurl]images/e2mlogosmall.png\"></a><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr><tr><td id=\"tdMap\" style=\"border-width:0px;vertical-align:top;\"><div id=\"divMap\" style=\"border-top-width:0px;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;background-color:transparent;position:relative;\"></div><img style=\"position:absolute;bottom:-15px;left:-18px;\" src=\"[siteurl]images/map_templates/easy2map_map_shadow_left.png\" /></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert18)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert19 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map On Top - Drop Shadow Left', '', 2,
            '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings height=\"120px\" max-width=\"2048px\" min-width=\"10px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\" style=\"position:relative;\"><tr><td id=\"tdMap\" style=\"border-width:0px;vertical-align:top;\"><div id=\"divMap\" style=\"background-color:transparent;border-style:solid;border-width:1px;border-bottom-width:0px;border-color:transparent;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"></div></td></tr><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-top-width:0px;border-color:#FFFFFF;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:0px;position:relative;\"><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div><img style=\"position:absolute;bottom:-15px;left:-18px;\" src=\"[siteurl]images/map_templates/easy2map_map_shadow_left.png\" /></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert19)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }

            $SQLInsert20 = "INSERT INTO `$map_templates_table`
            (`TemplateName`,
            `ExampleImage`,
            `DisplayOrder`,
            `CSSValues`,
            `CSSValuesPhoto`,
            `CSSValuesMap`,
            `TemplateHTML`,
            `Active`
            )
            VALUES
            ('Map On Top - Drop Shadow Right', '', 2,
            '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
            '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
            '<settings height=\"120px\" max-width=\"2048px\" min-width=\"10px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" />',
            '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\" style=\"position:relative;\"><tr><td id=\"tdMap\" style=\"border-width:0px;vertical-align:top;\"><div id=\"divMap\" style=\"background-color:transparent;border-style:solid;border-width:1px;border-bottom-width:0px;border-color:transparent;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"></div></td></tr><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-top-width:0px;border-color:#FFFFFF;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:0px;position:relative;\"><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div><img style=\"position:absolute;bottom:-15px;right:-18px;\" src=\"[siteurl]images/map_templates/easy2map_map_shadow_right.png\" /></td></tr></table></div>', 1)";

            if (!$wpdb->query($SQLInsert20)) {
                echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                return;
            }

        } else {

            $arrFound1 = $wpdb->get_results("SELECT ID FROM `$map_templates_table` 
                WHERE TemplateName = 'Map On Bottom - Drop Shadow Right'");
            if (count($arrFound1) === 0) {

                $SQLInsert21 = "INSERT INTO `$map_templates_table`
                (`TemplateName`,
                `ExampleImage`,
                `DisplayOrder`,
                `CSSValues`,
                `CSSValuesPhoto`,
                `CSSValuesMap`,
                `TemplateHTML`,
                `Active`
                )
                VALUES
                ('Map On Bottom - Drop Shadow Right', '', 1,
                '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
                '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
                '<settings height=\"120px\" max-width=\"2048px\" min-width=\"10px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" />',
                '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\" style=\"position:relative;\"><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-bottom-width:0px;top:0px;left:0px;min-width:10px;margin-bottom:0px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"><div align=\"center\" id=\"easy2mapslidertext\"></div><a class=\"easy2maplogo\" id=\"easy2mapphotologo\" target=\"_blank\" href=\"http://easy2map.com\"><img src=\"[siteurl]images/e2mlogosmall.png\"></a><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr><tr><td id=\"tdMap\" style=\"border-width:0px;vertical-align:top;\"><div id=\"divMap\" style=\"border-top-width:0px;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;background-color:transparent;position:relative;\"></div><img style=\"position:absolute;bottom:-15px;right:-17px;\" src=\"[siteurl]images/map_templates/easy2map_map_shadow_right.png\" /></td></tr></table></div>', 1)";

                if (!$wpdb->query($SQLInsert21)) {
                    echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                    return;
                }
            }

            $arrFound2 = $wpdb->get_results("SELECT ID FROM `$map_templates_table` 
                WHERE TemplateName = 'Map On Bottom - Drop Shadow Left'");
            if (count($arrFound2) === 0) {

                $SQLInsert22 = "INSERT INTO `$map_templates_table`
                (`TemplateName`,
                `ExampleImage`,
                `DisplayOrder`,
                `CSSValues`,
                `CSSValuesPhoto`,
                `CSSValuesMap`,
                `TemplateHTML`,
                `Active`
                )
                VALUES
                ('Map On Bottom - Drop Shadow Left', '', 1,
                '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
                '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
                '<settings height=\"120px\" max-width=\"2048px\" min-width=\"10px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" />',
                '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\" style=\"position:relative;\"><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-bottom-width:0px;top:0px;left:0px;min-width:10px;margin-bottom:0px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"><div align=\"center\" id=\"easy2mapslidertext\"></div><a class=\"easy2maplogo\" id=\"easy2mapphotologo\" target=\"_blank\" href=\"http://easy2map.com\"><img src=\"[siteurl]images/e2mlogosmall.png\"></a><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div></td></tr><tr><td id=\"tdMap\" style=\"border-width:0px;vertical-align:top;\"><div id=\"divMap\" style=\"border-top-width:0px;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;background-color:transparent;position:relative;\"></div><img style=\"position:absolute;bottom:-15px;left:-18px;\" src=\"[siteurl]images/map_templates/easy2map_map_shadow_left.png\" /></td></tr></table></div>', 1)";

                if (!$wpdb->query($SQLInsert22)) {
                    echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                    return;
                }
            }

            $arrFound3 = $wpdb->get_results("SELECT ID FROM `$map_templates_table` 
                WHERE TemplateName = 'Map On Top - Drop Shadow Left'");
            if (count($arrFound3) === 0) {


                $SQLInsert23 = "INSERT INTO `$map_templates_table`
                (`TemplateName`,
                `ExampleImage`,
                `DisplayOrder`,
                `CSSValues`,
                `CSSValuesPhoto`,
                `CSSValuesMap`,
                `TemplateHTML`,
                `Active`
                )
                VALUES
                ('Map On Top - Drop Shadow Left', '', 2,
                '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
                '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
                '<settings height=\"120px\" max-width=\"2048px\" min-width=\"10px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" />',
                '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\" style=\"position:relative;\"><tr><td id=\"tdMap\" style=\"border-width:0px;vertical-align:top;\"><div id=\"divMap\" style=\"background-color:transparent;border-style:solid;border-width:1px;border-bottom-width:0px;border-color:transparent;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"></div></td></tr><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-top-width:0px;border-color:#FFFFFF;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:0px;position:relative;\"><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div><img style=\"position:absolute;bottom:-15px;left:-18px;\" src=\"[siteurl]images/map_templates/easy2map_map_shadow_left.png\" /></td></tr></table></div>', 1)";

                if (!$wpdb->query($SQLInsert23)) {
                    echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                    return;
                }

            }

            $arrFound4 = $wpdb->get_results("SELECT ID FROM `$map_templates_table` 
                    WHERE TemplateName = 'Map On Top - Drop Shadow Right'");
                if (count($arrFound4) === 0) {


                $SQLInsert25 = "INSERT INTO `$map_templates_table`
                (`TemplateName`,
                `ExampleImage`,
                `DisplayOrder`,
                `CSSValues`,
                `CSSValuesPhoto`,
                `CSSValuesMap`,
                `TemplateHTML`,
                `Active`
                )
                VALUES
                ('Map On Top - Drop Shadow Right', '', 2,
                '<settings background-color=\"#FFFFFF\" border-style=\"solid\" border-width=\"1px\" border-color=\"#EBEBEB\" margin-left=\"auto\" margin-right=\"auto\" />',
                '<settings font-weight=\"bold\" color=\"#FFFFFF\" font-size=\"0.9em\" font-family=\"Arial, Helvetica, sans-serif\" width=\"420px\" height=\"390px\" max-width=\"2048px\" min-width=\"10px\" border-style=\"solid\" border-radius=\"0px\" border-width=\"1px\" border-color=\"#faf9f9\" background-color=\"#faf9f9\" />',
                '<settings height=\"120px\" max-width=\"2048px\" min-width=\"10px\" border-radius=\"0px\" border-style=\"solid\" border-width=\"1px\" border-color=\"#faf9f9\" />',
                '<div style=\"margin:auto;\"><table cellpadding=\"1\" cellspacing=\"1\" id=\"divMapParent\" style=\"position:relative;\"><tr><td id=\"tdMap\" style=\"border-width:0px;vertical-align:top;\"><div id=\"divMap\" style=\"background-color:transparent;border-style:solid;border-width:1px;border-bottom-width:0px;border-color:transparent;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:5px;position:relative;\"></div></td></tr><tr><td><div align=\"center\" id=\"easy2mapmainimage\" style=\"text-align:center;border-style:solid;border-width:1px;border-top-width:0px;border-color:#FFFFFF;background-color:#FFFFFF;top:0px;left:0px;min-width:10px;margin-bottom:5px;margin-left:5px;margin-right:5px;margin-top:0px;position:relative;\"><div align=\"center\" id=\"easy2mapslidertext\"></div><div id=\"easy2mapslider\"><a class=\"easy2mapbutton easy2mapprev\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/prev.png\"></a><a class=\"easy2mapbutton easy2mapnext\" href=\"#\" rel=\"nofollow\"><img src=\"[siteurl]images/next.png\"></a><div class=\"easy2mapholder_cont\"><ul id=\"Easy2MapSliderParent\" class=\"easy2mapholder\"></ul></div><div class=\"easy2mapclear\"></div></div></div><img style=\"position:absolute;bottom:-15px;right:-18px;\" src=\"[siteurl]images/map_templates/easy2map_map_shadow_right.png\" /></td></tr></table></div>', 1)";

                if (!$wpdb->query($SQLInsert25)) {
                    echo sprintf($error, __("Could not add data to easy2map templates table.", 'easy2mapimg'));
                    return;
                } 

            }

        }


        $result = $wpdb->get_var("show tables like '$map_themes_table'");

        if (strtolower($result) != strtolower($map_themes_table)) {

            $SQL = "CREATE TABLE `$map_themes_table` (
                `ID` int(11) NOT NULL AUTO_INCREMENT,
                `ThemeName` varchar(256) DEFAULT NULL,
                `Styles` text,
                `Version` varchar(128) DEFAULT NULL,
                PRIMARY KEY (`ID`),
                UNIQUE KEY `ID_UNIQUE` (`ID`)
                ) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8";

            if (!$wpdb->query($SQL)) {
                echo sprintf($error, __("Could not create easy2map photos themes table.", 'easy2map'));
                return;
            }

            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (1, 'No Theme','','" . self::e2m_version . "');");
            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (2, 'Subtle Greyscale','[{\"featureType\":\"landscape\",\"stylers\":[{\"saturation\":-100},{\"lightness\":65},{\"visibility\":\"on\"}]},{\"featureType\":\"poi\",\"stylers\":[{\"saturation\":-100},{\"lightness\":51},{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.highway\",\"stylers\":[{\"saturation\":-100},{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.arterial\",\"stylers\":[{\"saturation\":-100},{\"lightness\":30},{\"visibility\":\"on\"}]},{\"featureType\":\"road.local\",\"stylers\":[{\"saturation\":-100},{\"lightness\":40},{\"visibility\":\"on\"}]},{\"featureType\":\"transit\",\"stylers\":[{\"saturation\":-100},{\"visibility\":\"simplified\"}]},{\"featureType\":\"administrative.province\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"water\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"on\"},{\"lightness\":-25},{\"saturation\":-100}]},{\"featureType\":\"water\",\"elementType\":\"geometry\",\"stylers\":[{\"hue\":\"#ffff00\"},{\"lightness\":-25},{\"saturation\":-97}]}]','" . self::e2m_version . "');");
            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (3, 'Blue Essence','[{\"featureType\":\"landscape.natural\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"visibility\":\"on\"},{\"color\":\"#e0efef\"}]},{\"featureType\":\"poi\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"visibility\":\"on\"},{\"hue\":\"#1900ff\"},{\"color\":\"#c0e8e8\"}]},{\"featureType\":\"road\",\"elementType\":\"geometry\",\"stylers\":[{\"lightness\":100},{\"visibility\":\"simplified\"}]},{\"featureType\":\"road\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"transit.line\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"on\"},{\"lightness\":700}]},{\"featureType\":\"water\",\"elementType\":\"all\",\"stylers\":[{\"color\":\"#7dcdcd\"}]}]','" . self::e2m_version . "');");
            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (4, 'Apple Maps-esque','[{\"featureType\":\"landscape.man_made\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#f7f1df\"}]},{\"featureType\":\"landscape.natural\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#d0e3b4\"}]},{\"featureType\":\"landscape.natural.terrain\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.business\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.medical\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#fbd3da\"}]},{\"featureType\":\"poi.park\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#bde6ab\"}]},{\"featureType\":\"road\",\"elementType\":\"geometry.stroke\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#ffe15f\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry.stroke\",\"stylers\":[{\"color\":\"#efd151\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#ffffff\"}]},{\"featureType\":\"road.local\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"black\"}]},{\"featureType\":\"transit.station.airport\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#cfb2db\"}]},{\"featureType\":\"water\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#a2daf2\"}]}]','" . self::e2m_version . "');");
            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (5, 'Blue Water','[{\"featureType\":\"administrative\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"color\":\"#444444\"}]},{\"featureType\":\"landscape\",\"elementType\":\"all\",\"stylers\":[{\"color\":\"#f2f2f2\"}]},{\"featureType\":\"poi\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road\",\"elementType\":\"all\",\"stylers\":[{\"saturation\":-100},{\"lightness\":45}]},{\"featureType\":\"road.highway\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"labels.icon\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"transit\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"water\",\"elementType\":\"all\",\"stylers\":[{\"color\":\"#46bcec\"},{\"visibility\":\"on\"}]}]','" . self::e2m_version . "');");
            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (6, 'Pale Dawn','[{\"featureType\":\"administrative\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"on\"},{\"lightness\":33}]},{\"featureType\":\"landscape\",\"elementType\":\"all\",\"stylers\":[{\"color\":\"#f2e5d4\"}]},{\"featureType\":\"poi.park\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#c5dac6\"}]},{\"featureType\":\"poi.park\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"on\"},{\"lightness\":20}]},{\"featureType\":\"road\",\"elementType\":\"all\",\"stylers\":[{\"lightness\":20}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#c5c6c6\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#e4d7c6\"}]},{\"featureType\":\"road.local\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#fbfaf7\"}]},{\"featureType\":\"water\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"on\"},{\"color\":\"#acbcc9\"}]}]','" . self::e2m_version . "');");
            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (7, 'Retro','[{\"featureType\":\"administrative\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"water\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"transit\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"landscape\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.highway\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.local\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"water\",\"stylers\":[{\"color\":\"#84afa3\"},{\"lightness\":52}]},{\"stylers\":[{\"saturation\":-17},{\"gamma\":0.36}]},{\"featureType\":\"transit.line\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#3f518c\"}]}]','" . self::e2m_version . "');");
            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (8, 'Paper','[{\"featureType\":\"administrative\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"landscape\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"simplified\"},{\"hue\":\"#0066ff\"},{\"saturation\":74},{\"lightness\":100}]},{\"featureType\":\"poi\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"},{\"weight\":0.6},{\"saturation\":-85},{\"lightness\":61}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.local\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"transit\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"water\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"simplified\"},{\"color\":\"#5f94ff\"},{\"lightness\":26},{\"gamma\":5.86}]}]','" . self::e2m_version . "');");
            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (9, 'Gowalla','[{\"featureType\":\"administrative.land_parcel\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"landscape.man_made\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"simplified\"},{\"lightness\":20}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry\",\"stylers\":[{\"hue\":\"#f49935\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"geometry\",\"stylers\":[{\"hue\":\"#fad959\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.local\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.local\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"transit\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"water\",\"elementType\":\"all\",\"stylers\":[{\"hue\":\"#a1cdfc\"},{\"saturation\":30},{\"lightness\":49}]}]','" . self::e2m_version . "');");
            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (10, 'Neutral Blue','[{\"featureType\":\"water\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#193341\"}]},{\"featureType\":\"landscape\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#2c5a71\"}]},{\"featureType\":\"road\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#29768a\"},{\"lightness\":-37}]},{\"featureType\":\"poi\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#406d80\"}]},{\"featureType\":\"transit\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#406d80\"}]},{\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"visibility\":\"on\"},{\"color\":\"#3e606f\"},{\"weight\":2},{\"gamma\":0.84}]},{\"elementType\":\"labels.text.fill\",\"stylers\":[{\"color\":\"#ffffff\"}]},{\"featureType\":\"administrative\",\"elementType\":\"geometry\",\"stylers\":[{\"weight\":0.6},{\"color\":\"#1a3541\"}]},{\"elementType\":\"labels.icon\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.park\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#2c5a71\"}]}]','" . self::e2m_version . "');");
            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (11, 'MapBox','[{\"featureType\":\"water\",\"stylers\":[{\"saturation\":43},{\"lightness\":-11},{\"hue\":\"#0088ff\"}]},{\"featureType\":\"road\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"hue\":\"#ff0000\"},{\"saturation\":-100},{\"lightness\":99}]},{\"featureType\":\"road\",\"elementType\":\"geometry.stroke\",\"stylers\":[{\"color\":\"#808080\"},{\"lightness\":54}]},{\"featureType\":\"landscape.man_made\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#ece2d9\"}]},{\"featureType\":\"poi.park\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#ccdca1\"}]},{\"featureType\":\"road\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"color\":\"#767676\"}]},{\"featureType\":\"road\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"color\":\"#ffffff\"}]},{\"featureType\":\"poi\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"landscape.natural\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"visibility\":\"on\"},{\"color\":\"#b8cb93\"}]},{\"featureType\":\"poi.park\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"poi.sports_complex\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"poi.medical\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"poi.business\",\"stylers\":[{\"visibility\":\"simplified\"}]}]','" . self::e2m_version . "');");
            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (12, 'becomeadinosaur','[{\"elementType\":\"labels.text\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"landscape.natural\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#f5f5f2\"},{\"visibility\":\"on\"}]},{\"featureType\":\"administrative\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"transit\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.attraction\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"landscape.man_made\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#ffffff\"},{\"visibility\":\"on\"}]},{\"featureType\":\"poi.business\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.medical\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.place_of_worship\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.school\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.sports_complex\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#ffffff\"},{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.arterial\",\"stylers\":[{\"visibility\":\"simplified\"},{\"color\":\"#ffffff\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"labels.icon\",\"stylers\":[{\"color\":\"#ffffff\"},{\"visibility\":\"off\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"labels.icon\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.arterial\",\"stylers\":[{\"color\":\"#ffffff\"}]},{\"featureType\":\"road.local\",\"stylers\":[{\"color\":\"#ffffff\"}]},{\"featureType\":\"poi.park\",\"elementType\":\"labels.icon\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi\",\"elementType\":\"labels.icon\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"water\",\"stylers\":[{\"color\":\"#71c8d4\"}]},{\"featureType\":\"landscape\",\"stylers\":[{\"color\":\"#e5e8e7\"}]},{\"featureType\":\"poi.park\",\"stylers\":[{\"color\":\"#8ba129\"}]},{\"featureType\":\"road\",\"stylers\":[{\"color\":\"#ffffff\"}]},{\"featureType\":\"poi.sports_complex\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#c7c7c7\"},{\"visibility\":\"off\"}]},{\"featureType\":\"water\",\"stylers\":[{\"color\":\"#a0d3d3\"}]},{\"featureType\":\"poi.park\",\"stylers\":[{\"color\":\"#91b65d\"}]},{\"featureType\":\"poi.park\",\"stylers\":[{\"gamma\":1.51}]},{\"featureType\":\"road.local\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.local\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"poi.government\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"landscape\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.local\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road\"},{\"featureType\":\"road\"},{},{\"featureType\":\"road.highway\"}]','" . self::e2m_version . "');");
            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (13, 'Avocado World','[{\"featureType\":\"water\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"on\"},{\"color\":\"#aee2e0\"}]},{\"featureType\":\"landscape\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#abce83\"}]},{\"featureType\":\"poi\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#769E72\"}]},{\"featureType\":\"poi\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"color\":\"#7B8758\"}]},{\"featureType\":\"poi\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"color\":\"#EBF4A4\"}]},{\"featureType\":\"poi.park\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"simplified\"},{\"color\":\"#8dab68\"}]},{\"featureType\":\"road\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"color\":\"#5B5B3F\"}]},{\"featureType\":\"road\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"color\":\"#ABCE83\"}]},{\"featureType\":\"road\",\"elementType\":\"labels.icon\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.local\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#A4C67D\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#9BBF72\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#EBF4A4\"}]},{\"featureType\":\"transit\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"administrative\",\"elementType\":\"geometry.stroke\",\"stylers\":[{\"visibility\":\"on\"},{\"color\":\"#87ae79\"}]},{\"featureType\":\"administrative\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#7f2200\"},{\"visibility\":\"off\"}]},{\"featureType\":\"administrative\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"color\":\"#ffffff\"},{\"visibility\":\"on\"},{\"weight\":4.1}]},{\"featureType\":\"administrative\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"color\":\"#495421\"}]},{\"featureType\":\"administrative.neighborhood\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]}]','" . self::e2m_version . "');");
            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (14, 'Bentley','[{\"featureType\":\"landscape\",\"stylers\":[{\"hue\":\"#F1FF00\"},{\"saturation\":-27.4},{\"lightness\":9.4},{\"gamma\":1}]},{\"featureType\":\"road.highway\",\"stylers\":[{\"hue\":\"#0099FF\"},{\"saturation\":-20},{\"lightness\":36.4},{\"gamma\":1}]},{\"featureType\":\"road.arterial\",\"stylers\":[{\"hue\":\"#00FF4F\"},{\"saturation\":0},{\"lightness\":0},{\"gamma\":1}]},{\"featureType\":\"road.local\",\"stylers\":[{\"hue\":\"#FFB300\"},{\"saturation\":-38},{\"lightness\":11.2},{\"gamma\":1}]},{\"featureType\":\"water\",\"stylers\":[{\"hue\":\"#00B6FF\"},{\"saturation\":4.2},{\"lightness\":-63.4},{\"gamma\":1}]},{\"featureType\":\"poi\",\"stylers\":[{\"hue\":\"#9FFF00\"},{\"saturation\":0},{\"lightness\":0},{\"gamma\":1}]}]','" . self::e2m_version . "');");
            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (15, 'Bright and Bubbly','[{\"featureType\":\"water\",\"stylers\":[{\"color\":\"#19a0d8\"}]},{\"featureType\":\"administrative\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"color\":\"#ffffff\"},{\"weight\":6}]},{\"featureType\":\"administrative\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"color\":\"#e85113\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry.stroke\",\"stylers\":[{\"color\":\"#efe9e4\"},{\"lightness\":-40}]},{\"featureType\":\"road.arterial\",\"elementType\":\"geometry.stroke\",\"stylers\":[{\"color\":\"#efe9e4\"},{\"lightness\":-20}]},{\"featureType\":\"road\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"lightness\":100}]},{\"featureType\":\"road\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"lightness\":-100}]},{\"featureType\":\"road.highway\",\"elementType\":\"labels.icon\"},{\"featureType\":\"landscape\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"landscape\",\"stylers\":[{\"lightness\":20},{\"color\":\"#efe9e4\"}]},{\"featureType\":\"landscape.man_made\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"water\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"lightness\":100}]},{\"featureType\":\"water\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"lightness\":-100}]},{\"featureType\":\"poi\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"hue\":\"#11ff00\"}]},{\"featureType\":\"poi\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"lightness\":100}]},{\"featureType\":\"poi\",\"elementType\":\"labels.icon\",\"stylers\":[{\"hue\":\"#4cff00\"},{\"saturation\":58}]},{\"featureType\":\"poi\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"on\"},{\"color\":\"#f0e4d3\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#efe9e4\"},{\"lightness\":-25}]},{\"featureType\":\"road.arterial\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#efe9e4\"},{\"lightness\":-10}]},{\"featureType\":\"poi\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"simplified\"}]}]','" . self::e2m_version . "');");
            $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (16, 'Nature','[{\"featureType\":\"landscape\",\"stylers\":[{\"hue\":\"#FFA800\"},{\"saturation\":0},{\"lightness\":0},{\"gamma\":1}]},{\"featureType\":\"road.highway\",\"stylers\":[{\"hue\":\"#53FF00\"},{\"saturation\":-73},{\"lightness\":40},{\"gamma\":1}]},{\"featureType\":\"road.arterial\",\"stylers\":[{\"hue\":\"#FBFF00\"},{\"saturation\":0},{\"lightness\":0},{\"gamma\":1}]},{\"featureType\":\"road.local\",\"stylers\":[{\"hue\":\"#00FFFD\"},{\"saturation\":0},{\"lightness\":30},{\"gamma\":1}]},{\"featureType\":\"water\",\"stylers\":[{\"hue\":\"#00BFFF\"},{\"saturation\":6},{\"lightness\":8},{\"gamma\":1}]},{\"featureType\":\"poi\",\"stylers\":[{\"hue\":\"#679714\"},{\"saturation\":33.4},{\"lightness\":-25.4},{\"gamma\":1}]}]','" . self::e2m_version . "');");

            
        } else {

            //does theme exist?
            $arrThemeSearch1 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 1");
            if (count($arrThemeSearch1) === 0) {
                $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (1, 'No Theme','','" . self::e2m_version . "');");
            }
            $arrThemeSearch2 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 2");
            if (count($arrThemeSearch2) === 0) {
                $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (2, 'Subtle Greyscale','[{\"featureType\":\"landscape\",\"stylers\":[{\"saturation\":-100},{\"lightness\":65},{\"visibility\":\"on\"}]},{\"featureType\":\"poi\",\"stylers\":[{\"saturation\":-100},{\"lightness\":51},{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.highway\",\"stylers\":[{\"saturation\":-100},{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.arterial\",\"stylers\":[{\"saturation\":-100},{\"lightness\":30},{\"visibility\":\"on\"}]},{\"featureType\":\"road.local\",\"stylers\":[{\"saturation\":-100},{\"lightness\":40},{\"visibility\":\"on\"}]},{\"featureType\":\"transit\",\"stylers\":[{\"saturation\":-100},{\"visibility\":\"simplified\"}]},{\"featureType\":\"administrative.province\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"water\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"on\"},{\"lightness\":-25},{\"saturation\":-100}]},{\"featureType\":\"water\",\"elementType\":\"geometry\",\"stylers\":[{\"hue\":\"#ffff00\"},{\"lightness\":-25},{\"saturation\":-97}]}]','" . self::e2m_version . "');");
            }
            $arrThemeSearch3 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 3");
            if (count($arrThemeSearch3) === 0) {
               $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (3, 'Blue Essence','[{\"featureType\":\"landscape.natural\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"visibility\":\"on\"},{\"color\":\"#e0efef\"}]},{\"featureType\":\"poi\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"visibility\":\"on\"},{\"hue\":\"#1900ff\"},{\"color\":\"#c0e8e8\"}]},{\"featureType\":\"road\",\"elementType\":\"geometry\",\"stylers\":[{\"lightness\":100},{\"visibility\":\"simplified\"}]},{\"featureType\":\"road\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"transit.line\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"on\"},{\"lightness\":700}]},{\"featureType\":\"water\",\"elementType\":\"all\",\"stylers\":[{\"color\":\"#7dcdcd\"}]}]','" . self::e2m_version . "');");
            }
            $arrThemeSearch4 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 4");
            if (count($arrThemeSearch4) === 0) {
               $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (4, 'Apple Maps-esque','[{\"featureType\":\"landscape.man_made\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#f7f1df\"}]},{\"featureType\":\"landscape.natural\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#d0e3b4\"}]},{\"featureType\":\"landscape.natural.terrain\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.business\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.medical\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#fbd3da\"}]},{\"featureType\":\"poi.park\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#bde6ab\"}]},{\"featureType\":\"road\",\"elementType\":\"geometry.stroke\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#ffe15f\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry.stroke\",\"stylers\":[{\"color\":\"#efd151\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#ffffff\"}]},{\"featureType\":\"road.local\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"black\"}]},{\"featureType\":\"transit.station.airport\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#cfb2db\"}]},{\"featureType\":\"water\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#a2daf2\"}]}]','" . self::e2m_version . "');");
            }
            $arrThemeSearch5 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 5");
            if (count($arrThemeSearch5) === 0) {
               $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (5, 'Blue Water','[{\"featureType\":\"administrative\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"color\":\"#444444\"}]},{\"featureType\":\"landscape\",\"elementType\":\"all\",\"stylers\":[{\"color\":\"#f2f2f2\"}]},{\"featureType\":\"poi\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road\",\"elementType\":\"all\",\"stylers\":[{\"saturation\":-100},{\"lightness\":45}]},{\"featureType\":\"road.highway\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"labels.icon\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"transit\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"water\",\"elementType\":\"all\",\"stylers\":[{\"color\":\"#46bcec\"},{\"visibility\":\"on\"}]}]','" . self::e2m_version . "');");
            }
            $arrThemeSearch6 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 6");
            if (count($arrThemeSearch6) === 0) {
               $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (6, 'Pale Dawn','[{\"featureType\":\"administrative\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"on\"},{\"lightness\":33}]},{\"featureType\":\"landscape\",\"elementType\":\"all\",\"stylers\":[{\"color\":\"#f2e5d4\"}]},{\"featureType\":\"poi.park\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#c5dac6\"}]},{\"featureType\":\"poi.park\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"on\"},{\"lightness\":20}]},{\"featureType\":\"road\",\"elementType\":\"all\",\"stylers\":[{\"lightness\":20}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#c5c6c6\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#e4d7c6\"}]},{\"featureType\":\"road.local\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#fbfaf7\"}]},{\"featureType\":\"water\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"on\"},{\"color\":\"#acbcc9\"}]}]','" . self::e2m_version . "');");
            }
            $arrThemeSearch7 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 7");
            if (count($arrThemeSearch7) === 0) {
               $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (7, 'Retro','[{\"featureType\":\"administrative\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"water\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"transit\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"landscape\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.highway\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.local\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"water\",\"stylers\":[{\"color\":\"#84afa3\"},{\"lightness\":52}]},{\"stylers\":[{\"saturation\":-17},{\"gamma\":0.36}]},{\"featureType\":\"transit.line\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#3f518c\"}]}]','" . self::e2m_version . "');");
            }
            $arrThemeSearch8 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 8");
            if (count($arrThemeSearch8) === 0) {
               $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (8, 'Paper','[{\"featureType\":\"administrative\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"landscape\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"simplified\"},{\"hue\":\"#0066ff\"},{\"saturation\":74},{\"lightness\":100}]},{\"featureType\":\"poi\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"},{\"weight\":0.6},{\"saturation\":-85},{\"lightness\":61}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.local\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"transit\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"water\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"simplified\"},{\"color\":\"#5f94ff\"},{\"lightness\":26},{\"gamma\":5.86}]}]','" . self::e2m_version . "');");
            }
            $arrThemeSearch9 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 9");
            if (count($arrThemeSearch9) === 0) {
               $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (9, 'Gowalla','[{\"featureType\":\"administrative.land_parcel\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"landscape.man_made\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"simplified\"},{\"lightness\":20}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry\",\"stylers\":[{\"hue\":\"#f49935\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"geometry\",\"stylers\":[{\"hue\":\"#fad959\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.local\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.local\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"transit\",\"elementType\":\"all\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"water\",\"elementType\":\"all\",\"stylers\":[{\"hue\":\"#a1cdfc\"},{\"saturation\":30},{\"lightness\":49}]}]','" . self::e2m_version . "');");
            }
            $arrThemeSearch10 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 10");
            if (count($arrThemeSearch10) === 0) {
               $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (10, 'Neutral Blue','[{\"featureType\":\"water\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#193341\"}]},{\"featureType\":\"landscape\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#2c5a71\"}]},{\"featureType\":\"road\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#29768a\"},{\"lightness\":-37}]},{\"featureType\":\"poi\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#406d80\"}]},{\"featureType\":\"transit\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#406d80\"}]},{\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"visibility\":\"on\"},{\"color\":\"#3e606f\"},{\"weight\":2},{\"gamma\":0.84}]},{\"elementType\":\"labels.text.fill\",\"stylers\":[{\"color\":\"#ffffff\"}]},{\"featureType\":\"administrative\",\"elementType\":\"geometry\",\"stylers\":[{\"weight\":0.6},{\"color\":\"#1a3541\"}]},{\"elementType\":\"labels.icon\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.park\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#2c5a71\"}]}]','" . self::e2m_version . "');");
            }
            $arrThemeSearch11 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 11");
            if (count($arrThemeSearch11) === 0) {
                $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (11, 'MapBox','[{\"featureType\":\"water\",\"stylers\":[{\"saturation\":43},{\"lightness\":-11},{\"hue\":\"#0088ff\"}]},{\"featureType\":\"road\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"hue\":\"#ff0000\"},{\"saturation\":-100},{\"lightness\":99}]},{\"featureType\":\"road\",\"elementType\":\"geometry.stroke\",\"stylers\":[{\"color\":\"#808080\"},{\"lightness\":54}]},{\"featureType\":\"landscape.man_made\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#ece2d9\"}]},{\"featureType\":\"poi.park\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#ccdca1\"}]},{\"featureType\":\"road\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"color\":\"#767676\"}]},{\"featureType\":\"road\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"color\":\"#ffffff\"}]},{\"featureType\":\"poi\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"landscape.natural\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"visibility\":\"on\"},{\"color\":\"#b8cb93\"}]},{\"featureType\":\"poi.park\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"poi.sports_complex\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"poi.medical\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"poi.business\",\"stylers\":[{\"visibility\":\"simplified\"}]}]','" . self::e2m_version . "');");
            } 
            $arrThemeSearch12 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 12");
            if (count($arrThemeSearch12) === 0) {
                $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (12, 'becomeadinosaur','[{\"elementType\":\"labels.text\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"landscape.natural\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#f5f5f2\"},{\"visibility\":\"on\"}]},{\"featureType\":\"administrative\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"transit\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.attraction\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"landscape.man_made\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#ffffff\"},{\"visibility\":\"on\"}]},{\"featureType\":\"poi.business\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.medical\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.place_of_worship\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.school\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi.sports_complex\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#ffffff\"},{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.arterial\",\"stylers\":[{\"visibility\":\"simplified\"},{\"color\":\"#ffffff\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"labels.icon\",\"stylers\":[{\"color\":\"#ffffff\"},{\"visibility\":\"off\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"labels.icon\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.arterial\",\"stylers\":[{\"color\":\"#ffffff\"}]},{\"featureType\":\"road.local\",\"stylers\":[{\"color\":\"#ffffff\"}]},{\"featureType\":\"poi.park\",\"elementType\":\"labels.icon\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"poi\",\"elementType\":\"labels.icon\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"water\",\"stylers\":[{\"color\":\"#71c8d4\"}]},{\"featureType\":\"landscape\",\"stylers\":[{\"color\":\"#e5e8e7\"}]},{\"featureType\":\"poi.park\",\"stylers\":[{\"color\":\"#8ba129\"}]},{\"featureType\":\"road\",\"stylers\":[{\"color\":\"#ffffff\"}]},{\"featureType\":\"poi.sports_complex\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#c7c7c7\"},{\"visibility\":\"off\"}]},{\"featureType\":\"water\",\"stylers\":[{\"color\":\"#a0d3d3\"}]},{\"featureType\":\"poi.park\",\"stylers\":[{\"color\":\"#91b65d\"}]},{\"featureType\":\"poi.park\",\"stylers\":[{\"gamma\":1.51}]},{\"featureType\":\"road.local\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.local\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"on\"}]},{\"featureType\":\"poi.government\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"landscape\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road.local\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road\"},{\"featureType\":\"road\"},{},{\"featureType\":\"road.highway\"}]','" . self::e2m_version . "');");
            }
            $arrThemeSearch13 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 13");
            if (count($arrThemeSearch13) === 0) {
                $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (13, 'Avocado World','[{\"featureType\":\"water\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"on\"},{\"color\":\"#aee2e0\"}]},{\"featureType\":\"landscape\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#abce83\"}]},{\"featureType\":\"poi\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#769E72\"}]},{\"featureType\":\"poi\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"color\":\"#7B8758\"}]},{\"featureType\":\"poi\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"color\":\"#EBF4A4\"}]},{\"featureType\":\"poi.park\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"simplified\"},{\"color\":\"#8dab68\"}]},{\"featureType\":\"road\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"visibility\":\"simplified\"}]},{\"featureType\":\"road\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"color\":\"#5B5B3F\"}]},{\"featureType\":\"road\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"color\":\"#ABCE83\"}]},{\"featureType\":\"road\",\"elementType\":\"labels.icon\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"road.local\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#A4C67D\"}]},{\"featureType\":\"road.arterial\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#9BBF72\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry\",\"stylers\":[{\"color\":\"#EBF4A4\"}]},{\"featureType\":\"transit\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"administrative\",\"elementType\":\"geometry.stroke\",\"stylers\":[{\"visibility\":\"on\"},{\"color\":\"#87ae79\"}]},{\"featureType\":\"administrative\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#7f2200\"},{\"visibility\":\"off\"}]},{\"featureType\":\"administrative\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"color\":\"#ffffff\"},{\"visibility\":\"on\"},{\"weight\":4.1}]},{\"featureType\":\"administrative\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"color\":\"#495421\"}]},{\"featureType\":\"administrative.neighborhood\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]}]','" . self::e2m_version . "');");
            }
            $arrThemeSearch14 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 14");
            if (count($arrThemeSearch14) === 0) {
                $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (14, 'Bentley','[{\"featureType\":\"landscape\",\"stylers\":[{\"hue\":\"#F1FF00\"},{\"saturation\":-27.4},{\"lightness\":9.4},{\"gamma\":1}]},{\"featureType\":\"road.highway\",\"stylers\":[{\"hue\":\"#0099FF\"},{\"saturation\":-20},{\"lightness\":36.4},{\"gamma\":1}]},{\"featureType\":\"road.arterial\",\"stylers\":[{\"hue\":\"#00FF4F\"},{\"saturation\":0},{\"lightness\":0},{\"gamma\":1}]},{\"featureType\":\"road.local\",\"stylers\":[{\"hue\":\"#FFB300\"},{\"saturation\":-38},{\"lightness\":11.2},{\"gamma\":1}]},{\"featureType\":\"water\",\"stylers\":[{\"hue\":\"#00B6FF\"},{\"saturation\":4.2},{\"lightness\":-63.4},{\"gamma\":1}]},{\"featureType\":\"poi\",\"stylers\":[{\"hue\":\"#9FFF00\"},{\"saturation\":0},{\"lightness\":0},{\"gamma\":1}]}]','" . self::e2m_version . "');");
            }
            $arrThemeSearch15 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 15");
            if (count($arrThemeSearch15) === 0) {
                $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (15, 'Bright and Bubbly','[{\"featureType\":\"water\",\"stylers\":[{\"color\":\"#19a0d8\"}]},{\"featureType\":\"administrative\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"color\":\"#ffffff\"},{\"weight\":6}]},{\"featureType\":\"administrative\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"color\":\"#e85113\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry.stroke\",\"stylers\":[{\"color\":\"#efe9e4\"},{\"lightness\":-40}]},{\"featureType\":\"road.arterial\",\"elementType\":\"geometry.stroke\",\"stylers\":[{\"color\":\"#efe9e4\"},{\"lightness\":-20}]},{\"featureType\":\"road\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"lightness\":100}]},{\"featureType\":\"road\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"lightness\":-100}]},{\"featureType\":\"road.highway\",\"elementType\":\"labels.icon\"},{\"featureType\":\"landscape\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"landscape\",\"stylers\":[{\"lightness\":20},{\"color\":\"#efe9e4\"}]},{\"featureType\":\"landscape.man_made\",\"stylers\":[{\"visibility\":\"off\"}]},{\"featureType\":\"water\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"lightness\":100}]},{\"featureType\":\"water\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"lightness\":-100}]},{\"featureType\":\"poi\",\"elementType\":\"labels.text.fill\",\"stylers\":[{\"hue\":\"#11ff00\"}]},{\"featureType\":\"poi\",\"elementType\":\"labels.text.stroke\",\"stylers\":[{\"lightness\":100}]},{\"featureType\":\"poi\",\"elementType\":\"labels.icon\",\"stylers\":[{\"hue\":\"#4cff00\"},{\"saturation\":58}]},{\"featureType\":\"poi\",\"elementType\":\"geometry\",\"stylers\":[{\"visibility\":\"on\"},{\"color\":\"#f0e4d3\"}]},{\"featureType\":\"road.highway\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#efe9e4\"},{\"lightness\":-25}]},{\"featureType\":\"road.arterial\",\"elementType\":\"geometry.fill\",\"stylers\":[{\"color\":\"#efe9e4\"},{\"lightness\":-10}]},{\"featureType\":\"poi\",\"elementType\":\"labels\",\"stylers\":[{\"visibility\":\"simplified\"}]}]','" . self::e2m_version . "');");
            }
            $arrThemeSearch16 = $wpdb->get_results("SELECT ID FROM `$map_themes_table` WHERE ID = 16");
            if (count($arrThemeSearch16) === 0) {
                $wpdb->query("INSERT INTO `$map_themes_table` (ID, ThemeName, Styles, Version) VALUES (16, 'Nature','[{\"featureType\":\"landscape\",\"stylers\":[{\"hue\":\"#FFA800\"},{\"saturation\":0},{\"lightness\":0},{\"gamma\":1}]},{\"featureType\":\"road.highway\",\"stylers\":[{\"hue\":\"#53FF00\"},{\"saturation\":-73},{\"lightness\":40},{\"gamma\":1}]},{\"featureType\":\"road.arterial\",\"stylers\":[{\"hue\":\"#FBFF00\"},{\"saturation\":0},{\"lightness\":0},{\"gamma\":1}]},{\"featureType\":\"road.local\",\"stylers\":[{\"hue\":\"#00FFFD\"},{\"saturation\":0},{\"lightness\":30},{\"gamma\":1}]},{\"featureType\":\"water\",\"stylers\":[{\"hue\":\"#00BFFF\"},{\"saturation\":6},{\"lightness\":8},{\"gamma\":1}]},{\"featureType\":\"poi\",\"stylers\":[{\"hue\":\"#679714\"},{\"saturation\":33.4},{\"lightness\":-25.4},{\"gamma\":1}]}]','" . self::e2m_version . "');");
            }
        }
    }

    /**     * Create custom post-type menu */
    public static function create_admin_menu() {
        add_menu_page('Easy2Map Photo Maps', // page title
                'Easy2MapPhotos', // menu title
                'manage_options', // capability 
                self::admin_menu_slug, // menu slug 
                'Easy2MapImg::get_admin_page', // callback 
                plugins_url('images/e2m_favicon2020.png', dirname(__FILE__)) //default icon
        );

        //add_submenu_page(self::admin_menu_slug, 'Enter Easy2MapPhotos Activation Code', 'Activation', 'manage_options', 'wp-easy2mapphotos-activation', 'Easy2MapImg::easy2mapimg_admin_validation');

        /* if (current_user_can('edit_posts') || current_user_can('edit_pages')){

          if(get_user_option('rich_editing') == 'true')
          {
          add_filter("mce_external_plugins", "Easy2MapImg::add_easy2mapimg_tinymce_plugin");
          add_filter('mce_buttons', 'Easy2MapImg::register_easy2mapimg_button');
          }
          } */
    }

    /* public static function add_easy2mapimg_tinymce_plugin($plugin_array) {
      $plugin_array['easy2map'] = plugins_url('easy2map-tinymce.php', dirname(__FILE__));
      return $plugin_array;
      }

      function register_easy2mapimg_button($buttons) {
      array_push($buttons, "|", "easy2map");
      return $buttons;
      } */

    /** Prints the administration page for this plugin. */
    public static function get_admin_page() {

        if (isset($_GET["action"]) && strcasecmp($_GET["action"], "addeditpins") == 0 && isset($_GET["map_id"])) {
            include('AddEditMapPins.php');
        } else if (isset($_GET["action"]) && strcasecmp($_GET["action"], "edit") == 0 && isset($_GET["map_id"])) {
            //include('AddEditMaps.php');
            //include('MapAdminister.php');
            include('MapAdmin.php');
        } else if (isset($_GET["action"]) && strcasecmp($_GET["action"], "mappiniconsave") == 0 && isset($_GET["map_id"])) {
            include('MapPinIconSave.php');
        } else if (isset($_GET["action"]) && strcasecmp($_GET["action"], "copymapsettings") == 0 && isset($_GET["map_id"])) {
            include('CopyMapSettings.php');
        } else if (isset($_GET["action"]) && strcasecmp($_GET["action"], "mappinimageupload") == 0 && isset($_GET["map_id"])) {
            include('MapPinImageUpload.php');
        } else if (isset($_GET["action"]) && strcasecmp($_GET["action"], "mappreview") == 0 && isset($_GET["map_id"])) {
            include('MapPreview.php');
        } else if (isset($_GET["action"]) && strcasecmp($_GET["action"], "copymapsettings") == 0 && isset($_GET["map_id"])) {
            include('CopyMapSettings.php');
        } else if (isset($_GET["action"]) && strcasecmp($_GET["action"], "photoimport") == 0 && isset($_GET["map_id"])) {
            include('ZipPhotoImport.php');
        } else if (isset($_GET["action"]) && strcasecmp($_GET["action"], "activation") == 0) {
            include('Validation.php');
        } else {
            include('ImageMapManager.php');
        }
    }

    /** Validation fucntion */
    private static function easy2MapPhotoCodeValidator($code) {

        if (strlen($code) == "")
            $code = get_option('phe_171323_transient_17666766');

        //code validator
        $validation = true;
        $string = substr($code, 32, -32);
        $pie_1 = substr($code, 0, 32);
        $pie_2 = substr($code, -32, 32);
        //get integers + characters in string
        $regex_first = "/[0-9]+/";
        $regex_second = "/[A-z]+/";
        preg_match_all($regex_first, $string, $integers);
        preg_match_all($regex_second, $string, $characters);
        //divide integer by key number
        $integer1 = $integers[0][0] / 3137831;
        $integer2 = $integers[0][1] / 7713;
        //validate integers
        $regex_decimal = "/[.]/";
        if (preg_match($regex_decimal, $integers[0][0]) || $integer1 <= 2211 || $integer1 >= 5353 || preg_match($regex_decimal, $integers[0][1]) || $integer2 <= 1001 || $integer2 >= 10201) {
            $validation = false;
        }
        //validate characters
        $regex_characters1 = "/[^ACEGIKMOQSUWY]/";
        $regex_characters2 = "/[^bdfhjlnprtvxz]/";
        if (preg_match($regex_characters1, $characters[0][0]) || preg_match($regex_characters2, $characters[0][1])) {
            $validation = false;
        }
        //validate MD5
        $val_1 = $string[3] . $string[15] . $string[7] . $string[4] . $string[9] . $string[13] . $string . $string[2] . $string[1] * $string[3];
        $val_2 = $string[5] . $string[1] . $string . $string[17] . $string[8] . $string[7] . $string[11] . $string[6] . $string[4] * $string[2];
        if (md5($val_1) != $pie_1 || md5($val_2) != $pie_2) {
            $validation = false;
        }
        return $validation;
    }

    /** Validation page. */
    public static function easy2mapimg_admin_validation() {
        include('Validation.php');
    }

    /**
     * * _is_searchable_page * 
     * * Any page that's not in the WP admin area is considered searchable. 
     * * @return boolean Simple true/false as to whether the current page is searchable. */
    private static function _is_searchable_page() {
        if (is_admin()) {
            return false;
        } else {
            return true;
        }
    }

    public static function retrieve_map($raw_args, $content = null) {
        $defaults = array('id' => '',);
        $sanitized_args = shortcode_atts($defaults, $raw_args);
        if (empty($sanitized_args['id'])) {
            return '';
        }

        $mapHTML = easy2mapimg_retrieve_map_HTML($sanitized_args['id']);
        $mapHTML = str_ireplace("divMapParent", "easy2mapImgMapParent" . $sanitized_args['id'], $mapHTML);
        $mapHTML = str_ireplace("divMap", "easy2mapimg_canvas_" . $sanitized_args['id'], $mapHTML);

        $mapHTML = str_ireplace("easy2mapmainimage", "easy2mapmainimage" . $sanitized_args['id'], $mapHTML);
        $mapHTML = str_ireplace("easy2mapslider", "easy2mapslider" . $sanitized_args['id'], $mapHTML);

        $sliderBG = plugins_url('/images/bg_grey.png', dirname(__FILE__));
        $waitingBG = plugins_url('/images/busy.gif', dirname(__FILE__));

        return '<script>var $easy2mapphotowaitingImage = "' . $waitingBG . '";</script><style type="text/css">
            #easy2mapslider' . $sanitized_args['id'] . 'text {display:none;float:right;clear:both;width:96%;margin:10px ;z-index:999;border-color:transparent;border-radius:0px;border-style:solid;border-width:1px;text-shadow:#171717 0.1em 0.1em 0.1em;background-color:transparent;}
            #easy2mapslider' . $sanitized_args['id'] . ' {padding-top:6px;display:none;position: absolute; bottom:0px;left:0px;z-index:99999;width: 100%; vertical-align: middle; height:67px;background-image: url(' . $sliderBG . '); background-repeat: repeat; }
            #easy2mapslider' . $sanitized_args['id'] . ' .easy2mapholder_cont {width: 100%; margin: 0 auto; overflow: hidden;  height:60px;}
            #easy2mapslider' . $sanitized_args['id'] . ' .easy2mapholder { vertical-align:middle; margin-left: 43px; margin-right: 37px; background-image: url(' . $sliderBG . '); background-repeat: repeat; }
            #easy2mapslider' . $sanitized_args['id'] . ' .easy2mapslide {cursor:pointer; vertical-align:middle; margin-top:auto;margin-bottom:auto;position: relative; margin-right: 8px; float:left; min-width: 60px; height: 60px;}
            #easy2mapslider' . $sanitized_args['id'] . ' .easy2mapbutton {position: absolute;}
            #easy2mapslider' . $sanitized_args['id'] . ' .easy2mapprev {top: 25px; margin-left:5px;left:0px;}
            #easy2mapslider' . $sanitized_args['id'] . ' .easy2mapnext {top: 25px; margin-right:5px;right:0px;}
            .easy2mapclear {clear:both;}
            .easy2maplogo{position: absolute; bottom:2px;right:2px;z-index:99999;}
            #easy2mapimg_canvas_' . $sanitized_args['id'] . ' img {
                max-width: none !important;
                border-radius: 0px !important;
                background: transparent;
                box-shadow: 0 0 0 transparent !important;
            }      
            #easy2mapslider' . $sanitized_args['id'] . ' img {
                max-width: none !important;
                border-radius: 0px !important;
                border-width:0px;
                box-shadow: 0 0 0 transparent !important;
            }
            #easy2mapslider' . $sanitized_args['id'] . ' ul {
                list-style-type: none;
                padding: 0; margin: 0;
                border-width:0px;
            }
            #easy2mapslider' . $sanitized_args['id'] . ' ul li {
                list-style: none;
                padding: 0; margin: 0;
                border-width:0px;
            }
            #easy2mapimg_canvas_' . $sanitized_args['id'] . ' table, td {
              margin: -1.5em 0 !important;
              padding: 0px !important;
              border-width:0px;
            }
            #easy2mapImgMapParent' . $sanitized_args['id'] . '{
                width:30px;
            }
            </style><input type="hidden" id="easy2mapimg_ajax_url_' . $sanitized_args['id'] . '" value="' . admin_url("admin-ajax.php") . '">' . $mapHTML;
    }

}

?>